==> axiom-1.2.22-src.zip: axiom-1.2.22/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/dimension/serialization/XML.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.dimension.serialization;

import java.io.IOException;
import java.io.PrintStream;

import javax.xml.transform.stream.StreamSource;

import org.xml.sax.InputSource;

/**
 * Encapsulates serialized XML data. In contrast to {@link InputSource} or {@link StreamSource} the
 * data can be read multiple times.
 */
public interface XML {
    /**
     * Get an {@link InputSource} object for the XML data.
     * 
     * @return the XML data as an {@link InputSource} object
     */
    InputSource getInputSource();
    
    /**
     * Dump the XML data to the given stream.
     * 
     * @param out
     *            the stream to write the XML data to
     * @throws IOException 
     */
    void dump(PrintStream out) throws IOException;
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/dimension/serialization/XML.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.dimension.serialization;

import java.io.IOException;
import java.io.PrintStream;

import javax.xml.transform.stream.StreamSource;

import org.xml.sax.InputSource;

/**
 * Encapsulates serialized XML data. In contrast to {@link InputSource} or {@link StreamSource} the
 * data can be read multiple times.
 */
public interface XML {
    /**
     * Get an {@link InputSource} object for the XML data.
     *
     * @return the XML data as an {@link InputSource} object
     */
    InputSource getInputSource();

    /**
     * Dump the XML data to the given stream.
     *
     * @param out the stream to write the XML data to
     * @throws IOException
     */
    void dump(PrintStream out) throws IOException;
}
